<?php
/**
 * @file
 * Views field handlers for Subscriptions.
 */

/**
 * A handler to provide a field with a link to view the subscription.
 *
 * @ingroup views_field_handlers
 */
class subs_handler_view extends views_handler_field {

  function construct() {
    parent::construct();

    $this->additional_fields['sid'] = 'sid';
    $this->additional_fields['type'] = 'type';
  }

  function option_definition() {
    $options = parent::option_definition();
    $options['text'] = array('default' => '', 'translatable' => TRUE);
    return $options;
  }

  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $form['text'] = array(
      '#type' => 'textfield',
      '#title' => t('Text to display'),
      '#default_value' => $this->options['text'],
    );
  }

  function query() {
    $this->ensure_my_table();
    $this->add_additional_fields();
  }

  function render($values) {
    $text = !empty($this->options['text']) ? $this->options['text'] : t('view');
    $sid = $values->{$this->aliases['sid']};
    return l($text, 'subscription/' . $sid);
  }

}

/**
 * A handler to provide a field with a link to edit the subscription.
 *
 * @ingroup views_field_handlers
 */
class subs_handler_edit extends subs_handler_view {
  function construct() {
    parent::construct();
    $this->additional_fields['type'] = 'type';
  }


  function render($values) {
    $type = $values->{$this->aliases['type']};
    $sid = $values->{$this->aliases['sid']};

    // Creating a dummy subscription to check access against.
    $dummy = (object) array('sid' => $sid, 'type' => $type);
    if (!subs_access('edit', $dummy)) {
      return;
    }

    $text = !empty($this->options['text']) ? $this->options['text'] : t('edit');
    $sid = $values->{$this->aliases['sid']};

    return l($text, 'subscription/' . $sid . '/edit');
  }
}

/**
 * A handler to provide a field with a link to delete the subscription.
 *
 * @ingroup views_field_handlers
 */
class subs_handler_delete extends subs_handler_view {
  function construct() {
    parent::construct();
    $this->additional_fields['type'] = 'type';
  }


  function render($values) {
    $type = $values->{$this->aliases['type']};
    $sid = $values->{$this->aliases['sid']};

    // Creating a dummy subscription to check access against.
    $dummy = (object) array('sid' => $sid, 'type' => $type);
    if (!subs_access('delete', $dummy)) {
      return;
    }

    $text = !empty($this->options['text']) ? $this->options['text'] : t('delete');
    $sid = $values->{$this->aliases['sid']};

    return l($text, 'subscription/' . $sid . '/delete');
  }
}